
# q-expansion of newform 399.2.bo.b, downloaded from the LMFDB on 15 November 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 399
weight = 2
poly_data = [1, 18, 339, -120, 1476, -2445, 7150, -8208, 9162, -5773, 4005, -1788, 1063, -369, 177, -41, 18, -3, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[1724640021542767919, 21098817013182021662, 15237209695540201746, -50694327564871510233, -2358391355702597357, 133448121732140594211, -207988685224039480092, 163452220167537086371, -104656261696741507307, 51165325262854536119, -29904177175629238919, 11393447280832554477, -5122112106518195255, 1042795199584345228, -535979481703354162, 66295456266682472, -29551652107868190, -5027896185120053], 27319142924626383594], [[237467810441292156, -94364855123317926, -1771271740415853600, 16196623311932976726, -6309559399279016826, 1159843636260016233, 13405840245098751420, -11383293018762842880, 10393076025748401806, -5258170036108840437, 3369739749870412356, -1459151971464690096, 696542503026599334, -224708901752639991, 78154745957162314, -22401817158702420, 5568025118276442, -964152485141125], 4553190487437730599], [[656201623115748583, -19362448662339470648, 17356974312588132339, -160934801358313814817, 118862806975288622801, -158546051609293566303, -14065165376697096471, 28811025822469459619, -69030279206238680287, 37582472689586844805, -26462454541443351250, 13595725207469810307, -6462944979107756860, 2830702020868659746, -761465188990551299, 323243334038413594, -62140531384790628, 21967145994872603], 27319142924626383594], [[-987778833826626373, -29989231655195755024, 21265568798054507364, -273892611178087028145, 378413764822665326320, -1059533423270122099077, 1082014273327070738298, -1262184542558402511689, 746874976800850013698, -548906572957833044407, 229455293883691235749, -145212438032825398005, 47028207699613280692, -24269571370235471810, 5207453141562315041, -2468681572896868468, 379722490259229231, -138715775070373007], 27319142924626383594], [[-1210528496914907212, 9094026874843056872, -32705345135120227296, 157398623925017098494, -368074552708163834477, 976449955047121587483, -1260887868910765343040, 1364933749664940951682, -910201039002860204189, 603600875461906432343, -283596849342516111656, 161241082111967001576, -59220178683624492767, 26880991147741655779, -6605084156679240835, 2740233546263384261, -488597631414037419, 151755468218445763], 27319142924626383594], [[-20938836444723585808, 191751942288424805223, -168397679315488873101, 1129261554414588835366, -2366900754494381610309, 5144773955224008878182, -5748213363977958721109, 5725147089340061509030, -3622732032401400829973, 2372517682652727482110, -1091865935427414500169, 610842841469558619563, -217630938935006601890, 98138803497513940136, -23885101512272355720, 9772156726823398335, -1689062145916907831, 514111524627860707], 27319142924626383594], [[31174077878422945142, 205095375923650637298, 82190606584423984857, 849690788743556285707, -1445866916908711719132, 4705906770654299464921, -5414913948356533828883, 6081149550192727197733, -3825834442936803414464, 2654549955120016426165, -1186884227338428276711, 704005270351148500589, -244969100950579886873, 116909152480478050490, -27227509881784105497, 11873769747468265122, -1990572015342118352, 656201623115748583], 27319142924626383594], [[36278833816281671053, -330800289846896662586, 313611136701919095434, -1585737610225513957935, 3001069650452132930818, -6659606456934602564243, 7411472680244192011862, -7522224084321849869807, 4755749388084394124624, -3138302193957156397049, 1439670710246087241075, -811119636821382083681, 289185243020571840162, -130923166406307305764, 31821564342375440307, -13074115902347916072, 2269070238928680809, -693001874559082133], 27319142924626383594], [[287828772516394500, -89076003043197242578, 69656508309354762891, -558852446487525937318, 947991538355372709717, -2636816996974700964663, 3032767677641181640071, -3408102864169549386774, 2151104671818952615659, -1500382591251714656963, 666896776635389786999, -399512083320879507378, 138132216036519033254, -66896414912723235125, 15361023147539490726, -6821554071369831477, 1128958050223381265, -382512906195735393], 9106380974875461198], [[-4368785443066576734, -82272859480013894484, 44692760564888035446, -356812047610626239082, 581768640165219337653, -1684489004410140163980, 1937752495083363173568, -2165287003237370331466, 1365643499641470776151, -947688841067504672424, 423133293097565684832, -251731739996066962494, 87400913151084165573, -41953647702151549298, 9713778410934275976, -4268852562824982366, 711439278838735343, -237467810441292156], 4553190487437730599], [[-18964865232106464832, -561217969388931485109, 310235464652858208048, -2686066112294322138575, 4920519588884935300194, -12850539705841748770169, 14784787158963885610156, -15878054202513128040857, 10077188223575750510200, -6840059478479346285779, 3098245220253261629640, -1801042378408465615780, 633729062002840490320, -296953459209353233552, 70195123641572655258, -30033511246606769067, 5092624291892370478, -1643980456942374956], 27319142924626383594], [[9944703374587800880, 569415757607458122795, -156262475020260640047, 2547927063152828045801, -4350192974404208156166, 12539164839254830100942, -14319297516990576165523, 15905808139071581181185, -10007512169629253732506, 6937087463454414754514, -3095049805799301593649, 1838414455006480493152, -637434963148865707339, 305797263294773275825, -70776536339520167151, 31073072039877690732, -5168892168443183704, 1724640021542767919], 27319142924626383594], [[716952350447138505, -284086732521259956998, 173874511815557516301, -1385127635555910934165, 2432001656930784683088, -6537789597071699433729, 7496027694004074969507, -8159366123883544194007, 5156851316503636969950, -3528597191057984192171, 1588657193788274979916, -931264348757731363791, 325872957884803498811, -153933468736985762904, 36129876604231065486, -15592084447691918904, 2628683675332320075, -856568229602682537], 9106380974875461198], [[804454271929158789, 15153040166038457090, -5374426699250581097, 66566542252127309703, -114095713445825144148, 337278851252602320266, -389409229600167327729, 433878386211955344787, -273506364985382341290, 189482973657467272794, -84693390081169286014, 50281215894704207345, -17465182090607363349, 8360742612857675109, -1940224748291764544, 849773682299123361, -141829710887673777, 47076437003426518], 479283209203971642], [[-16651321566692598802, -975909414822644624032, 465051238231238575675, -4489783189843104745332, 7477831642436076164651, -20540895588368150456722, 23237782521492094515139, -25618076958241626127402, 16083251011113434088349, -11116376757904800381046, 4960714265972477933673, -2938214930457619447420, 1019333605954125019434, -487284007766665995248, 113074895859445947894, -49431610135573523676, 8243028521118439249, -2731995132305367772], 27319142924626383594], [[-33296031151847772400, -978841163432038528522, 410026729140086058184, -4172183310777211086852, 7283138505784445810591, -20517181099258877119231, 23713738493701219301542, -26028172366904514430102, 16463848710664288368667, -11300980544946658768735, 5084132735234860067820, -2989820560130816303560, 1045193946192112807323, -495167978227776638549, 115983642432352517973, -50221973425857596847, 8453572796106408055, -2765060586471941971], 27319142924626383594]]

hecke_ring_character_values = [[134, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [115, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [211, [0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0], [1, -1, -1, 0, 0, 0, 0, 0, 0, 1, 1, 0, -1, 0, -1, 0, -1, 1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0], [1, 1, 0, 0, 0, 0, 0, -1, -1, 1, 0, 1, 0, 1, -1, 0, 0, 1], [-1, 0, 0, 0, 0, 2, 0, -1, 0, -1, 0, -1, -1, 1, 1, 2, -1, 1], [-1, 0, 0, -1, -1, 0, 0, 0, -1, -1, 0, -1, 0, 0, 0, 0, 0, 0], [-2, 2, 2, -1, 1, -1, 0, 0, -1, -2, -2, -1, 0, 0, 1, 0, 2, -2], [-1, 1, -1, 1, 0, 0, 0, 1, -3, -1, 0, -1, -3, 0, 0, 1, 1, 0], [0, -2, 0, -2, 1, -1, 2, 0, 4, 2, 0, 0, 0, 0, 0, 2, 0, 0], [0, 0, 2, -1, 2, -2, 2, 0, 1, -1, -1, 5, 0, 1, 0, 0, 2, 0], [-1, 0, 0, -1, 0, 0, 0, 2, -2, 0, 0, 0, -2, -2, -1, -1, -1, 1], [2, 0, 0, 1, -1, 2, 0, 0, -1, -1, -1, 1, 1, 2, 0, 1, -1, -1], [-2, 0, 1, -4, -1, 4, 0, -2, 2, 0, -1, -2, 2, 2, 2, 1, 0, -2], [1, -2, -1, -1, -3, 3, 0, -2, 2, 3, 2, -1, 0, 1, 0, 1, -2, 0], [4, -4, -1, 1, -1, 0, -1, -2, -2, 4, 4, 2, -2, -2, -2, -2, -6, 4], [3, 1, 0, 0, -2, 2, -1, -1, 3, 0, 1, 1, 2, 0, 1, 1, -1, 1], [0, 4, 2, -2, -2, 0, 3, 0, 3, -2, -3, 0, 3, 0, 5, 4, 7, -3], [-5, -1, 0, 2, -1, 1, -2, 2, -3, 1, 3, -3, 0, -5, 1, -2, -4, 0], [0, 2, 2, 0, 2, 0, 0, -2, -3, -4, 0, 3, 0, 2, 3, 3, 4, -3], [0, 0, -1, -1, 1, -2, -1, 0, -2, 1, 1, -2, -2, 4, 0, -1, -2, 1], [1, -3, 0, -3, 3, -3, 0, 0, 4, 3, 3, 5, 5, 0, -2, -3, 1, 1], [0, 1, 0, 0, 1, 0, 1, -1, 5, 2, -1, 2, -1, 6, 0, 0, -1, -3], [-3, -2, -2, -4, 0, 0, -4, -3, 0, 2, 0, -4, 0, 4, -2, -3, 1, -7], [1, -3, 0, -2, -1, -1, 0, 1, 1, -1, 2, -2, 3, 0, 2, -1, -2, -1], [0, -2, -2, -1, 0, -4, -1, 0, 0, 3, 0, -2, -4, 2, -3, -2, -1, 1], [-2, 0, 0, 0, 0, 1, -1, 2, 5, 0, 5, -2, 3, -5, 3, 0, 0, 0], [0, 5, 3, 4, 2, -3, 2, 3, 2, -2, -1, 1, 3, -1, 0, -4, 3, 1], [-1, -3, -5, 0, 2, 0, 0, 1, 2, 4, 5, -2, 1, -1, -3, 2, -4, 3], [4, 3, 2, -1, 1, 1, 1, 1, -1, -6, -3, 0, -2, -2, 2, 2, 6, -3], [-1, 0, 0, -3, 0, 0, -3, -1, 0, 3, 0, -3, -2, 3, -3, -4, 1, -4], [6, -1, 0, 0, 1, -1, 2, -3, 6, 0, 0, 7, -1, 0, 0, 0, 0, 0], [6, 4, -3, 3, -5, 0, 1, -4, -6, 0, 0, 4, -6, -2, 2, 2, 2, 0], [-1, 1, 1, 2, 0, -1, 2, -1, 0, 0, 0, -3, 8, 3, 0, -2, 2, 1], [-1, 1, -3, 1, -1, 3, -3, 0, -2, -3, -3, -3, -3, 2, 0, 3, 3, -3], [4, 0, -4, 3, -4, 0, 0, 11, -11, 0, 0, 0, -5, -5, -1, -1, 3, -3], [0, -4, -5, -1, -5, 1, 0, -2, 4, 6, -1, -4, 0, 2, -2, -3, -6, 2], [1, 0, -2, 0, 2, 1, -3, 4, -1, 0, -3, 1, -5, 1, 0, 0, 0, 0], [1, 2, 1, -1, -3, 0, 0, 0, 4, 0, -3, 0, 4, -1, 1, -2, 1, -3], [-3, 2, 0, -1, -4, 3, 1, -5, -3, 0, 1, 4, -7, 0, 1, 0, -1, 0], [-3, 2, 1, 0, -1, 3, -2, -5, 3, -1, -4, -3, 8, -3, 3, 0, 0, -1], [3, 0, 6, 1, 3, -3, 5, -2, -2, -2, -5, 1, 0, 3, 3, 3, 2, 0], [-11, 2, 4, -3, 6, -2, -2, 1, -1, -4, -2, 0, 3, 3, 3, 3, 0, 2], [-3, -5, -1, -4, 4, -5, -1, 0, 3, 6, 6, 0, 0, 2, -5, -6, -8, 1], [0, -3, 2, -6, 6, -2, 6, 5, 7, 1, -3, 5, 5, 2, 0, 1, 2, -4], [-4, 7, -1, 2, -1, 1, -3, -5, 5, -3, -4, -9, 0, -4, 1, 1, 3, 0], [-5, 0, 0, 3, 2, 1, 1, 0, -5, -4, 1, -2, -3, 0, 1, 5, -1, 5], [-2, 8, 3, 4, 5, -4, 0, -6, -2, -2, -3, 2, 2, 6, 1, -2, 2, -1], [3, 0, 0, 6, 0, 0, 0, 6, -6, 0, 0, 0, -9, -9, 2, 2, 3, -3], [-2, -3, -6, 4, 1, -7, -7, 8, -8, 6, 3, 0, -6, -6, -10, -10, -3, 0], [6, -2, 0, 2, -3, -2, 0, -1, -5, -3, -1, 5, -6, 1, 3, 2, 3, -3], [17, -8, 0, 0, 0, -3, 3, 5, 3, -1, 4, 17, -2, -3, 1, 0, 0, -1], [-5, 2, 2, 2, 0, -7, 2, -5, 0, 3, 0, 1, -7, -1, -3, -6, 3, 2], [-1, 4, -3, 3, -1, 0, -2, 9, -9, 3, -3, -9, -9, -8, 1, -5, -2, -3], [5, -4, 5, 1, 4, -4, 4, 0, 6, -2, 0, 5, 0, 5, -4, -2, 4, 0], [0, 0, 1, 3, -3, 7, 1, 0, -6, -4, -4, -6, -6, 8, 4, 4, 0, 0], [1, 4, 0, -2, 2, -3, 0, 0, 8, -3, -3, 9, 9, 5, -1, 3, 10, -4], [6, 2, -4, 0, -4, 0, 0, 11, -4, -9, -6, 4, -6, -11, 6, 0, 9, -6], [-1, -4, -2, 0, 2, -1, -1, 8, 10, 4, -3, -1, 2, -10, -8, 0, 0, 4], [2, 0, 6, -6, 3, 0, 9, -1, 5, 1, 3, 1, 5, -1, 7, 9, 6, 3], [-4, 4, 0, 0, -5, 5, -5, -5, -4, 1, 1, -9, 5, 0, 1, 3, -1, 3], [-7, 1, 4, 0, -4, 2, 2, -6, 2, 2, 2, -7, 8, -2, 5, 0, 0, 2], [4, 5, 0, 4, -4, 5, 0, 0, -2, -6, -6, 2, 2, -9, 5, 6, 9, -1], [0, 1, 10, -1, 7, -10, 7, 11, 12, -2, -2, 2, 11, 1, 0, -4, 4, 0], [7, -8, -2, -5, -7, 7, 3, -10, -6, 6, 5, -3, 0, 7, 5, 1, -10, 0], [-7, -2, -2, -10, 0, 3, -10, -7, 0, 5, 0, -2, 5, 2, -5, -6, 1, -1], [15, -12, 0, 0, 0, -3, 3, 8, 6, 2, 5, 15, -2, -6, -2, 0, 0, 2], [1, 5, 6, 6, 5, -6, 0, -3, -15, 0, 0, 15, -1, 3, -3, -3, 0, 3], [4, 2, 1, 8, 5, -8, 0, 9, -1, -9, 3, 1, -4, -9, 1, 4, 9, -1], [0, 5, 5, 9, 6, -5, 6, 1, 0, 0, 4, 6, 1, -1, 0, -5, -4, 4], [8, 4, 7, 0, -7, 1, 6, 1, -5, -3, -1, 8, -6, 5, 10, 0, 0, -3], [2, 1, 0, -2, -7, 5, 1, -12, 2, 7, 4, -1, 3, 0, 4, -5, -4, -5], [-7, 2, 2, 1, 0, 0, 1, -7, 0, -6, 0, 0, -8, 0, 6, 8, -2, -2], [0, -1, 0, 5, -7, 0, -7, -1, 2, 3, 6, -5, -1, 3, 0, 1, -9, 3], [7, 1, -2, 2, -1, -1, -1, 7, -7, -2, -1, 0, -1, -1, -5, -5, 8, -7], [2, -3, -10, 5, -5, 4, -10, 0, -9, 4, 4, -7, -7, 5, 0, -4, -15, 4], [-4, -5, 4, -1, 6, -6, 5, 14, -3, -3, 0, 10, 0, -4, 3, -3, -3, 0], [-2, 1, 0, -5, -3, -2, -4, -1, -2, 2, -3, -2, 0, 0, -3, 5, 3, 5], [-1, -2, 0, -10, -5, -5, -1, 4, -1, 1, -3, 8, -9, 0, -3, -10, 3, -10], [-7, -9, -2, 0, -13, 13, -2, -2, -2, 5, 11, -9, 0, -7, 3, -6, -14, 0], [-4, -4, 8, 1, -1, 9, 9, -6, 6, 8, 4, 0, 12, 12, 5, 5, -15, 11], [8, -6, -5, 5, -5, 7, -5, 0, -1, 4, 4, 7, 7, -3, 3, -4, -15, 7], [-1, 4, 4, 9, 0, -7, 9, -1, 0, 5, 0, 4, 4, -4, -5, -5, 0, 3], [-3, 5, 1, -1, -4, 0, 1, 1, 17, -4, -5, -1, 17, 2, 2, 1, 6, -5], [-8, 0, 0, 4, 9, -5, -4, 9, -8, -4, -5, -2, -6, 0, -5, 6, 5, 6], [1, -5, -5, -1, 0, 4, -1, 1, 0, 6, 0, 3, 1, -3, -6, 4, -10, 15], [0, -1, 0, -6, -3, 0, -3, 1, -7, -5, -5, 5, 1, -8, 0, 7, 10, 0], [-5, 0, 9, -1, 5, 4, 4, -9, 9, 0, 0, 0, 11, 11, 2, 2, 7, -7], [6, -3, -2, 4, -5, -4, 0, 3, 2, 8, -2, -2, -6, -3, -4, -6, -8, 4], [0, -10, -4, -4, 6, 4, 6, 8, 12, 2, 6, 6, 8, 4, 0, -2, -8, 4], [12, 0, -5, 0, 5, -9, 4, 7, 12, 9, 1, 12, 5, -12, -9, 0, 0, 9], [-3, 10, 5, -5, 1, 0, 7, 2, 6, -4, -8, -2, 6, 1, 6, 2, 10, -8], [0, -8, 2, -9, 8, -2, 8, 4, 8, 2, -1, 12, 4, 4, 0, 3, -1, -3], [8, 6, 1, 3, -3, -3, 1, 0, -15, 0, 0, -7, -7, 2, 1, 0, 9, 1], [-1, 4, 5, 4, 7, -4, 0, 7, 1, -12, 3, -1, 1, -7, 0, 3, 12, 0], [4, -7, -2, -6, -9, 9, 4, -11, 5, 4, 3, -7, 0, 4, 5, 1, -8, 0], [-4, -6, -7, 7, 0, 0, -13, 10, -8, -1, 0, -10, -8, -6, -8, -7, -7, 0], [5, -4, -7, 0, 7, -5, -2, 0, -8, -4, -4, 5, -8, 8, -8, 0, 0, -4], [-6, -7, 2, -7, -1, 1, 9, 8, 9, -3, -2, 2, 0, -6, -2, -1, 4, 0], [7, 1, 0, -7, -7, 7, 7, -6, 5, 0, -8, 1, 0, 7, -5, 8, 13, 0], [-5, -2, -3, 3, -5, 0, -6, 2, -17, 0, -1, -2, -17, 3, -3, -4, -3, -1], [14, -9, -9, -5, 0, -5, -5, 14, 0, -2, 0, 2, -2, -2, 2, 2, 0, -4], [0, 2, 2, 2, 6, -2, 6, 0, -5, 1, 0, -14, 0, -5, 0, 4, -1, -1], [3, -7, -4, -13, -6, 2, 2, -8, 8, 14, 7, 0, 2, 2, -2, -2, -9, 2], [-15, 7, 6, -1, -1, 7, 7, -6, 6, -14, -7, 0, 8, 8, 6, 6, 9, -2], [0, -14, 3, -13, 5, -3, 5, 1, 12, 8, 1, 4, 1, 11, 0, -1, -9, -7], [-1, 1, 0, 2, 0, 2, 7, 2, -1, -8, 1, 8, -9, 0, 1, 6, -1, 6], [-11, -2, 0, 0, 8, 0, 3, 13, 5, 2, 5, -13, 5, -2, -6, -3, -8, 5], [-9, -8, -3, -2, -7, 7, -1, 2, 12, 7, 9, -7, 0, -9, 5, -2, -14, 0], [0, 6, 9, 8, 1, -9, 1, 8, -7, -4, 2, 0, 8, -15, 0, 0, 2, 6], [-4, -1, -2, 4, 4, -6, -6, 9, -9, 2, 1, 0, -5, -5, 0, 0, -10, 9], [9, 7, 5, 3, 0, -3, 0, -2, -1, -11, -7, 1, -9, 2, 7, 0, 11, -7], [-8, 10, -1, 0, 2, -2, -1, -3, 9, -5, -9, -11, 0, -8, -6, 4, 15, 0], [8, 3, -10, 0, 10, -2, -8, 10, -1, -1, -5, 8, -11, 1, -4, 0, 0, -1], [-15, -4, 8, -8, 10, 0, 7, -5, -10, -7, 3, 5, -10, 20, -5, 5, 2, 3], [6, -7, 6, 1, -1, -1, 0, 0, -1, 2, 6, 1, -6, 0, -3, 3, -2, 3], [6, 2, -2, 13, -13, 7, -2, 0, -3, 4, 4, 3, 3, -6, -1, -4, -14, 3], [7, 1, -3, 9, -3, 0, 0, -7, 7, -2, -1, 0, -11, -11, 3, 3, -4, 5], [0, -6, -4, -6, -2, 4, -2, 2, 1, -1, 0, -12, 2, -1, 0, 1, 1, 1], [-6, 11, 11, 0, 0, -6, 0, -6, 0, -5, 0, 1, 13, -1, 5, -3, 8, -2], [-3, -4, -11, 11, -4, 0, -4, 3, 9, 11, 11, -3, 9, 0, -3, -3, -14, 11], [-9, 4, 0, 0, 0, 8, -8, -4, 5, -4, 8, -9, 9, -5, 2, 0, 0, -4], [0, -6, -1, -7, 3, 1, 3, 0, 1, -1, -1, -9, 0, 1, 0, 1, 2, 0], [-7, 0, -2, 4, 9, -11, -11, 3, -3, 0, 0, 0, 7, 7, -11, -11, -4, 4], [0, 3, -3, 1, 2, 3, 2, 0, 4, 1, -2, -20, 0, 4, 0, 1, 1, -3], [-12, -1, 0, 6, 8, -2, 3, 5, -12, -12, -1, 5, -17, 0, -1, 4, 1, 4], [-3, -6, -6, -4, 0, 1, -4, -3, 0, 1, 0, -4, -2, 4, -1, -3, 2, -1], [1, -6, -15, 12, -12, 8, -15, 0, -6, 10, 10, -5, -5, -5, -8, -10, -12, 2], [-5, -3, -3, 0, 5, 0, 0, -1, -5, 4, 8, 5, 5, 1, -6, 2, -4, 6], [-6, 7, -1, 0, 1, -1, 0, -15, -2, -3, 5, -6, 13, 2, 14, 0, 0, -3], [10, -3, 0, -1, -5, 4, 2, -12, 10, 0, 7, 7, 3, 0, 7, -4, -7, -4], [12, -2, 0, -8, -3, -5, 16, -1, 12, 6, -3, 7, 5, 0, -3, -4, 3, -4], [9, 0, 2, -1, 4, -4, 3, -1, -1, -3, -3, 8, 0, 9, -6, 0, 9, 0], [-2, 12, 8, 4, -4, -3, 8, 0, 5, -5, -5, 3, 3, -24, 12, 5, 4, 7], [-14, -4, -5, -4, -4, -1, -1, 1, -1, 8, 4, 0, 7, 7, -13, -13, -3, -1], [16, 3, 0, -3, -8, 8, 3, -7, 2, 0, -6, 9, 0, 16, 4, 6, 2, 0], [-8, -7, -7, -4, 0, 12, -4, -8, 0, 3, 0, -8, 0, 8, -3, 9, -12, 2], [10, 8, -1, 0, 1, -5, 4, 9, 15, 2, 0, 10, 6, -15, 8, 0, 0, 2], [-20, 8, 7, -3, 4, 3, 3, 4, -4, -16, -8, 0, 0, 0, 13, 13, 4, 4], [8, 4, 2, 0, -2, 5, -3, -7, 11, -2, 11, 8, 18, -11, 9, 0, 0, -2], [7, -4, -4, -8, 0, 0, -8, 7, 0, 5, 0, 1, -10, -1, -5, -2, -3, -6], [-14, -5, 3, -3, 1, 0, -2, 14, -8, 0, 0, -14, -8, 0, -2, -2, -2, 0], [-13, 3, 3, -5, 0, -6, -5, -13, 0, -3, 0, -10, -5, 10, 3, -4, 7, -21], [-6, -3, -2, -8, -7, 7, 6, -1, 6, 10, -3, -7, 0, -6, 13, 13, -10, 0], [0, -3, 5, -6, 4, -5, 4, 2, -5, 0, -3, 15, 2, -7, 0, -5, 3, -3], [-10, 6, -11, 19, -19, 9, -11, 0, -7, 4, 4, -17, -17, -6, 3, -4, -23, 7], [-7, -1, 0, 4, 3, 1, -11, 11, -7, 2, 2, -2, -5, 0, 2, -13, -2, -13], [15, -7, 0, -3, -1, -2, 10, -12, 15, 3, 5, 10, 5, 0, 5, 1, -5, 1], [-6, -3, 1, -1, -10, 0, -6, 3, -22, 0, -4, -3, -22, 3, -4, -8, -4, -4], [3, 0, 1, 0, -1, -4, 5, -12, -9, 2, 7, 3, 3, 9, -6, 0, 0, 2], [2, -5, -6, 1, -1, -3, -6, 0, 8, 9, 9, 10, 10, -4, -8, -9, -15, 1], [0, 17, 1, 7, -1, -1, -1, -3, -1, -8, -10, 8, -3, 2, 0, -1, 18, -2], [-4, 2, 7, 9, 1, -1, -2, -8, 2, -9, 0, -12, 0, -4, -9, -9, 9, 0], [-3, 4, 4, -2, 0, -15, -2, -3, 0, 5, 0, 10, 16, -10, -5, -7, 2, 3], [0, -6, 1, -9, -5, 9, 0, -18, 11, -1, 1, -11, 0, 18, 2, 3, 1, -2], [-7, -1, 0, -1, -8, 8, 8, -20, 20, 2, 1, 0, 13, 13, 1, 1, -2, 1], [0, 1, -3, -11, 4, 3, 4, -1, -5, -5, -12, 1, -1, -4, 0, -2, 17, -7], [12, -5, 0, -1, -8, 7, 1, 7, 12, 7, 12, 15, -3, 0, 12, 11, -12, 11], [4, 9, 9, -1, 0, 3, -1, 4, 0, 6, 0, -3, 9, 3, -6, -6, 0, -6], [2, 8, -7, 2, -12, 12, -9, -11, -14, -3, 1, -9, 0, 2, -7, -4, 6, 0], [0, 16, 11, 5, -5, -7, 11, 0, 12, -4, -4, 12, 12, -1, 1, 4, 16, -3], [-11, -13, 10, -12, 12, -6, 10, 0, 28, 7, 7, 17, 17, 2, -2, -7, -9, 5], [7, 3, 0, -2, -7, 5, -4, -12, 7, 5, 2, 6, 1, 0, 2, 4, -2, 4], [20, -11, 0, 2, 10, -8, 6, 5, 20, -2, 3, 6, 14, 0, 3, 8, -3, 8], [-26, 13, -1, 0, 1, 3, -4, -13, -6, 3, -3, -26, 7, 6, 5, 0, 0, 3], [20, -13, -7, -3, -4, 3, 0, 8, -18, 3, 9, 18, -20, -8, -2, 7, -3, 2], [5, -3, -7, 2, -2, 7, -7, 0, -21, -2, -2, -16, -16, 11, 1, 2, 0, -1], [1, 6, -6, -6, -4, 4, 0, -3, -24, -1, -6, -2, 0, 1, 1, 5, 5, 0]]
